@@ -22,6 +22,9 @@ parser.add_argument(
     "-r", "--recursive", help="Search through folders recursively", type=bool
 )
 parser.add_argument("-e", "--errors", help="Expected number of errors", type=int)
+parser.add_argument(
+    "-i", "--ignore", help="files and folders to exclude. Seperated by comma ','"
+)
 args = parser.parse_args()
 
 
@@ -41,21 +44,7 @@ SCRIPT_PATH = os.path.realpath(__file__)
 SCRIPT_DIRECTORY = os.path.dirname(SCRIPT_PATH)
 XSD_DIRECTORY = os.path.join(SCRIPT_DIRECTORY, "xsd")
 
-# Configuration values from the end-user and/or GitHub Actions
-global root_folder
-root_folder = "**"
-if args.path is not None:
-    root_folder = args.path
-global recursive
-recursive = True
-if args.recursive is not None:
-    recursive = args.recursive
-global expected_error_count
-expected_error_count = 0
-if args.errors is not None:
-    expected_error_count = args.errors
-
-# Other global variables
+# global variables
 global error_count
 
 
@@ -68,6 +57,27 @@ file_ignore_list = [
     "seedmenu.xml",
 ]
 
+# Configuration values from the end-user and/or GitHub Actions
+global root_folder
+root_folder = "**"
+if args.path is not None:
+    root_folder = args.path
+
+global recursive
+recursive = True
+if args.recursive is not None:
+    recursive = args.recursive
+
+global expected_error_count
+expected_error_count = 0
+if args.errors is not None:
+    expected_error_count = args.errors
+
+global ignore_files
+ignore_files = []
+if args.ignore is not None:
+    file_ignore_list.extend(args.ignore.split(","))
+
 
 # ~~~~~~~~~~~~ Special conditions ~~~~~~~~~~~~
 
@@ -126,6 +136,19 @@ def is_valid_xml(file_path):
         return False
 
 
+def get_gitignore_files():
+    gitignore_path = root_folder.replace("**", "") + ".gitignore"
+    if not os.path.isfile(gitignore_path):
+        return []
+
+    ignoreLineStarts = ("\n", "#", "*")
+    with open(gitignore_path, "r") as f:
+        lines = f.readlines()
+        lines = [line for line in lines if not line.startswith(ignoreLineStarts)]
+        lines = [line.replace("\n", "") for line in lines]
+        return lines
+
+
 def main():
     printf("--- " + __package__ + " --- Version:", __version__)
 
@@ -137,6 +160,10 @@ def main():
     for ignoreFile in file_ignore_list:
         files = [f for f in files if ignoreFile not in f]
 
+    # if exists, remove all folders and files mentioned in the .gitignore file
+    for git_ignore_file in get_gitignore_files():
+        files = [f for f in files if git_ignore_file not in f]
+
     printf(f"Found {len(files)} files in path: {root_folder}/**.xml")
 
     for file_path in files:
@@ -246,6 +273,10 @@ def read_github_env_vars():
         expected_error_count = int(os.environ["INPUT_EXPECTEDERRORCOUNT"])
     printf("\tExpected Error Count: ", expected_error_count)
 
+    if "INPUT_IGNORE" in os.environ:
+        file_ignore_list.extend(os.environ["INPUT_IGNORE"].split(","))
+    printf("\tIgnored files: ", file_ignore_list)
+
 
 if __name__ == "__main__":
     read_github_env_vars()
